==> as-gui-0.6.22.tar.gz: as-gui-0.6.22/as_helpanel.h <==
//
//  OSSP asgui - Accounting system graphical user interface
//  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
//  Copyright (c) 2002-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
//  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
//  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
//
//  This file is part of OSSP asgui, an accounting system graphical user
//  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
//
//  Permission to use, copy, modify, and distribute this software for
//  any purpose with or without fee is hereby granted, provided that
//  the above copyright notice and this permission notice appear in all
//  copies.
//
//  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
//  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
//  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
//  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
//  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
//  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
//  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
//  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
//  SUCH DAMAGE.
//
//  as_helpanel.h: ISO C++ interface
//

#ifndef HELPANEL_H
#define HELPANEL_H

#include <qvariant.h>
#include <qdialog.h>


class QVBoxLayout;
class QHBoxLayout;
class QPushButton;
class QTextBrowser;

namespace AS {

class Helpanel : public QDialog
{
    Q_OBJECT

public:
    Helpanel(QWidget *pParent = 0, const char *kszName = 0,
        bool bModal = true, WFlags Flags = 0);
//    ~Helpanel(void); // No need to destroy widgets, because qt does it for us

public:
    QTextBrowser *m_pBrowser;
    QPushButton  *m_pDismissbutt;

protected:
    QVBoxLayout *m_pFormlay;
    QHBoxLayout *m_pButtlay;

protected slots:
    virtual void textChange(void);
};
} // namespace AS

#endif // HELPANEL_H

==> as-gui-0.6.23.tar.gz: as-gui-0.6.23/as_helpanel.h <==
//
//  OSSP asgui - Accounting system graphical user interface
//  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
//  Copyright (c) 2002-2003 Cable & Wireless Deutschland (http://www.cw.com/de/)
//  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
//  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
//
//  This file is part of OSSP asgui, an accounting system graphical user
//  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
//
//  Permission to use, copy, modify, and distribute this software for
//  any purpose with or without fee is hereby granted, provided that
//  the above copyright notice and this permission notice appear in all
//  copies.
//
//  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
//  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
//  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
//  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
//  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
//  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
//  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
//  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
//  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
//  SUCH DAMAGE.
//
//  as_helpanel.h: ISO C++ interface
//

#ifndef HELPANEL_H
#define HELPANEL_H

#include <qvariant.h>
#include <qdialog.h>


class QVBoxLayout;
class QHBoxLayout;
class QPushButton;
class QTextBrowser;

namespace AS {

class Helpanel : public QDialog
{
    Q_OBJECT

public:
    Helpanel(const QString &, QWidget *pParent = 0, const char *kszName = 0,
        bool bModal = true, WFlags Flags = 0);
//    ~Helpanel(void); // No need to destroy widgets, because qt does it for us

public:
    QTextBrowser *m_pBrowser;
    QPushButton  *m_pDismissbutt;

protected:
    QVBoxLayout *m_pFormlay;
    QHBoxLayout *m_pButtlay;

protected slots:
    virtual void textChange(void);
};
} // namespace AS

#endif // HELPANEL_H
